pub struct ProfileDef {
pub inherits: Vec<String>,
pub components: Vec<String>,
pub add: Vec<String>,
pub remove: Vec<String>,
}Expand description
Profile inheritance and component membership changes.
Fields
inherits: Vec<String>Profiles expanded before this profile’s own membership changes.
components: Vec<String>Base component or group references selected by the profile.
add: Vec<String>Components to add to the fully expanded profile in this configuration layer.
remove: Vec<String>Components to remove from the fully expanded profile in this configuration layer.