preview_plan

Function preview_plan 

pub fn preview_plan(plan: &ExecutionPlan) -> Result<InstallPreview, ForgeError>
Detect current tool and skill state for the components in an execution plan.

Errors

Returns ForgeError when detection environment preparation or a bounded worker fails.