pub struct InstallPreview {
pub tools: Vec<ToolStatus>,
pub skills: Vec<SkillStatus>,
}Expand description
Presentation-neutral detection snapshot produced before execution.
Fields
tools: Vec<ToolStatus>Tool statuses in canonical configuration order.
skills: Vec<SkillStatus>Skill statuses in canonical skill-and-agent order.
Implementations
Sourceimpl InstallPreview
impl InstallPreview
Sourcepub fn missing_tools(&self) -> Vec<&ToolStatus>
pub fn missing_tools(&self) -> Vec<&ToolStatus>
Return tools that are not currently detected as installed.
Sourcepub fn missing_skills(&self) -> Vec<&SkillStatus>
pub fn missing_skills(&self) -> Vec<&SkillStatus>
Return missing skills that have an installable agent destination.